from .tool import Tool
from .alphafold import AlphaFold
from .blastn import BLASTN
from .bowtie2 import Bowtie2
from .cellranger import CellRangerCount
from .clustalo import ClustalO
from .demucs import Demucs
from .diamond import DiamondBlastp, DiamondBlastx
from .kraken2 import Kraken2
from .megahit import Megahit
from .python3 import Python3
from .rapsearch2 import Rapsearch2
from .shi7 import Shi7
from .shogun import ShogunAlign, ShogunFilter
from .star import STARInstance
from .test import Test
from .unicycler import Unicycler
